import React, { useState, useEffect } from "react";

import Container from "react-bootstrap/Container";
import Row from "react-bootstrap/Row";
import Col from "react-bootstrap/Col";
import InputGroup from "react-bootstrap/InputGroup";
import Button from "react-bootstrap/Button";
import FormControl from "react-bootstrap/FormControl";

import Search from "./search";
import MenuDropDown from "./MenuDropDown";
import ItemGazette from "./ItemGazette";
import Pagination from "./Pagination";
import { Popup } from "./Popup";

export default function GazettesFunc(props) {
  const [gazettes, setgazettes] = useState([]);
  const [error, setError] = useState("");
  const [QValue, setQValue] = useState("");
  const [filteredData, setFilteredData] = useState(gazettes);
  let textInput = React.createRef();
  const [showPopup, setshowPopup] = useState(false);
  const [dep, setdep] = useState("unknown dep");
  const department = props.dep;
  const [suggestions, setsuggestions] = useState([]);
  const [Hint, setHint] = useState("");

  useEffect(() => {
    fetch(process.env.REACT_APP_API + "getalldata")
      .then((response) => {
        if (response.ok) return response.json();
        throw new Error("something went wrong while requesting posts");
      })
/*------------------------------------------------------------------------------------------*/
      .then((posts) => {
        console.log("right here" + posts[2].department);
        let r = [];
        r = posts.filter((data) => {
          if (department == "Guest") {
            return data;
          } else if (data.department == department) {
            return data;
          }
        });
        console.log(department);
        setgazettes(r);
        setFilteredData(r);
      })

/*---------------------------------------------------------------------------------------------*/
      .catch((error) => setError(error.message));
  }, []);

  const togglePopup = () => {
    setshowPopup((showPopup) => !showPopup);
  };

  const handleSearch = () => {
    let value = textInput.current.value.toLowerCase();
    setQValue(value);

    fetch(process.env.REACT_APP_API + "spellingChecker/" + value)
      .then((response) => {
        if (response.ok) return response.json();
        throw new Error("something went wrong while requesting posts");
      })
      .then((posts) => {
        console.log("suggestions " + posts.list);
        if (posts.list.length > 0) {
          setHint("Did you mean : ");
        }
        setsuggestions(posts.list);
      });

    let result = [];
    result = gazettes.filter((data) => {
      if (data.key != "value") {
        if (data.description.toLowerCase().includes(value)) {
          console.log(data);
          if (data.department == department) {
            return data;
          }
        }
        // return data[5].department.includes(value) != -1;
      }
    });
    setFilteredData(result);
  };

  if (error) return <h1>{error}</h1>;
  return (
    <div>
      <Row>
        <Col className="p-2" xs={12} md={8}></Col>
        <Col className="p-2 mr-2">
          <InputGroup className="mb-3">
            <FormControl placeholder="Start typing..." ref={textInput} />
            <Button
              variant="outline-secondary"
              id="button-addon2"
              onClick={() => handleSearch()}
            >
              Search Now 
            </Button>
          </InputGroup>
        </Col>
      </Row>

      <Container>
        <div>
          {filteredData.length > 0 ? (
            <>
              <Pagination
                data={filteredData}
                RenderComponent={ItemGazette}
                title="Search All Gazette Details"
                pageLimit={
                  filteredData.length <= 10
                    ? 1
                    : Math.round(filteredData.length / 10) + 1
                }
                dataLimit={10}
                query={QValue}
              />
            </>
          ) : (
            <>
              <p>
                {Hint}
                {suggestions.map((item) => (
                  <span
                    style={{
                      color: "chocolate",
                      marginLeft: 20,
                      fontWeight: "bold",
                      fontSize: 20,
                    }}
                  >
                    {item}
                  </span>
                ))}
              </p>
              {Hint == "" ? (
                <h1>Waiting for data...</h1>
              ) : (

                <h3>Check your search query...</h3> //Search 
                
              )}
            </>
          )}
        </div>
      </Container>
    </div>
  );
}

// export class Gazettes extends Component {
//   constructor(props) {
//     super(props);
//     this.state = { gazettes: [] };
//   }

//   refreshLIst() {
//     fetch(process.env.REACT_APP_API + "postvacancy") //later change this to
//       .then((response) => response.json())
//       .then((data) => {
//         // this.setState({ gazettes: data });
//       });
//   }

//   componentDidMount() {
//     // this.refreshLIst();
//   }

//   componentDidUpdate() {
//     // this.refreshLIst();
//   }

//   render() {
//     const { gazettes } = this.state;

//     const sampleSummary = [
//       {
//         id: "1",
//         cat: "General",
//         topic1: "Appointments by the President",
//         topic2: "Sri Lanka Nacy Regular Force",
//         topic3:
//           "Retirement and Transfer to the Regular Naval Reserve approved by his Excellency the President",
//         name: "HiS excellencythe President has approved the retirement of undermentioned senior officer from the Regular Naval force of Sri Lanka Navy with effect from 01st September 2021 and transfer to the Regular Naval Reserve on the same date.",
//       },
//       {
//         id: "2",
//         cat: "General",
//         topic1: "Appointments by the President",
//         topic2: "Sri Lanka Nacy Regular Force",
//         topic3:
//           "Retirement and Transfer to the Regular Naval Reserve approved by his Excellency the President",
//         name: "Summarized data, Summarized data, Summarized data, Summarized data, Summarized data, Summarized data, Summarized data, Summarized data, Summarized data, Summarized data, Summarized data, Summarized data, Summarized data, Summarized data, Summarized data, Summarized data, ",
//       },
//       {
//         id: "3",
//         cat: "General",
//         topic1: "Appointments by the President",
//         topic2: "Sri Lanka Nacy Regular Force",
//         topic3:
//           "Retirement and Transfer to the Regular Naval Reserve approved by his Excellency the President",
//         name: "We have yet another React post!",
//       },
//       {
//         id: "4",
//         cat: "General",
//         topic1: "Appointments by the President",
//         topic2: "Sri Lanka Nacy Regular Force",
//         topic3: "Promotion approved by his Excellency the President",
//         name: "This is the fourth and final post",
//       },
//     ];

//     return (
//       <div>
//         <Row>
//           <Col className="p-2" xs={12} md={8}>
//             <MenuDropDown />
//           </Col>
//           <Col className="p-2 mr-2">
//             <Search />
//           </Col>
//         </Row>

//         <Container>
//           {sampleSummary.map((ss) => (
//             <>
//               <Row>
//                 <Col className=" pt-2 title-text">{ss.cat}</Col>
//               </Row>
//               <Row className="pt-1 px-2 sub-title-text">{ss.topic3}</Row>
//               <Row className="p-2">{ss.name}</Row>
//             </>
//           ))}
//         </Container>
//       </div>
//     );
//   }
// }

/**
 * import React, { Component } from "react";
import { useState, useEffect } from "react";

import Container from "react-bootstrap/Container";
import Row from "react-bootstrap/Row";
import Col from "react-bootstrap/Col";

import Search from "./search";

export default function Gazettes() {
  const [data, setData] = useState([]);
  const getData = () => {
    fetch("http://127.0.0.1:8000/gazettemst/", {
      headers: {
        "Content-Type": "application/json",
        Accept: "application/json",
      },
    })
      .then(function (response) {
        console.log(response);
        return response.json();
      })
      .then(function (myJson) {
        console.log(myJson);
        setData(myJson);
      });
  };

  useEffect(() => {
    getData();
  }, []);

  return (
    <div className="App">
      {data && data.length > 0 && data.map((item) => <p>{item.GTitle}</p>)}
    </div>
  );
}
 */
