import React, { useEffect, useState } from "react";
import Container from "react-bootstrap/Container";
import Row from "react-bootstrap/Row";
import Col from "react-bootstrap/Col";
import Form from "react-bootstrap/Form";
import { Button } from "react-bootstrap";

import "reactjs-popup/dist/index.css";
import { NavLink } from "react-router-dom";
import Popup from "./Popup";

import Loader from "react-loader-spinner";
import { usePromiseTracker } from "react-promise-tracker";
import { trackPromise } from "react-promise-tracker";

const LoadingIndicator = (props) => {
  const { promiseInProgress } = usePromiseTracker();
  return (
    promiseInProgress && (
      <>
        <div
          style={{
            width: "100%",
            height: "100%",
            display: "flex",
            justifyContent: "center",
            alignItems: "center",
            padding: 20,
          }}
        >
          <Loader type="ThreeDots" color="#666666" height="50" width="50" />
          &nbsp;Reading Data... Please Wait &nbsp;
          <Loader type="ThreeDots" color="#666666" height="50" width="50" />
        </div>
      </>
    )
  );
};
//set default variable
export default function Vacancy() {
  const [vac, setVac] = useState([]);
  const [filteredData, setFilteredData] = useState(vac);

  const [selectedClient, setSelectedClient] = useState("");

  const [showPopup, setshowPopup] = useState(false);

  function handleSelectChange(event) {
    setSelectedClient(event.target.value);
    fetchVacancy();
    fetchVacancy();
  }
//fetch vacancy
  function fetchVacancy() {
    trackPromise(
      fetch(process.env.REACT_APP_API + "vacancy/" + selectedClient)
        .then(console.log("done"))
        .then((response) => response.json())
        .then((data) => {
          setVac(data);
          setFilteredData(data);
        })
    );
  }

  useEffect(() => {
    fetchVacancy();
    return () => {};
  }, []);
//refresh clustering vacancy
  function refreshData() {
    trackPromise(
      fetch(process.env.REACT_APP_API + "refreshClustering_Vacancy/")
        .then(console.log("done"))
        .then((response) => response.json())
        .then((data) => {
          // setVac(data);
          // setFilteredData(data);
        })
    );
  }
//set the popup
  const togglePopup = () => {
    setshowPopup((showPopup) => !showPopup);
  };
//set the category
  return (
    <>
      <div>
        <Form>
          <Container className="p-2 vacancy-container">
            <Row md={4}>
              <Col md={2} className="">
                <div key={1} className="mb-3">
                  <Form.Label style={{ padding: 5 }}>
                    Select Job Category
                  </Form.Label>
                </div>
              </Col>
              <Col xs={4}>
                <Form.Select
                  aria-label="Default select example"
                  value={selectedClient}
                  onChange={handleSelectChange}
                >
                  <option value="Select">-Select-</option>
                  <option value="Academic" onClick={handleSelectChange}>
                    Academic
                  </option>
                  <option value="Administrative" onClick={handleSelectChange}>
                    Administrative
                  </option>
                  <option value="Engineering" onClick={handleSelectChange}>
                    Engineering
                  </option>
                  <option value="Healthcare" onClick={handleSelectChange}>
                    Healthcare
                  </option>
                  <option value="Operations" onClick={handleSelectChange}>
                    Operations
                  </option>
                  <option value="Other" onClick={handleSelectChange}>
                    Other
                  </option>
                </Form.Select>
              </Col>
            </Row>
            <Row>
              <Col md={{ span: 3, offset: 3 }}></Col>
              <Col md={{ span: 3, offset: 3 }}>
                <Button onClick={refreshData}>Refresh Vacancies</Button>
              </Col>
            </Row>
          </Container>
        </Form>

        <Container>
          <LoadingIndicator />

          {filteredData.map((ss) => (
            <>
              {/* {text = ss.summary.substr(0,10)} */}
              <Row>
                <Col className=" pt-2 title-text">
                  <span>{ss.title}</span>
                  {/**show full description */}
                </Col>
              </Row>
              <Row className="pt-1 px-2 sub-title-text-2">
                {ss.summary}
                <br />
                <button onClick={togglePopup.bind()}>
                  Read Full Description
                </button>
                {showPopup ? (
                  <Popup
                    text={ss.description}
                    closePopup={togglePopup.bind()}
                  />
                ) : (
                  <span style={{ fontWeight: 600 }}>
                    <a
                      style={{ textDecoration: "none" }}
                      href={ss.url}
                      target="_blank"
                    >
                      Go to original Gazette PDF
                    </a>
                  </span>
                )}
                <br />
              </Row>
              {/* <Row className="p-2">{ss.summary}</Row> */}
            </>
          ))}
        </Container>
      </div>
    </>
  );
}